@@ -81,7 +81,7 @@ setClass(
 #'   `list` \tab `list`\cr
 #' }
 #'
-#' Given that the [list] consits of [RLum.Results-class] objects.
+#' Given that the [list] consists of [RLum.Results-class] objects.
 #'
 #' @md
 #' @name as
@@ -136,7 +136,7 @@ setMethod("show",
             cat("\n\t originator: ", object@originator, "()", sep = "")
             cat("\n\t data:", length(object@data))
             cat("\n", temp.type)
-            cat("\n\t additional info elements: ", length(object@info))
+            cat("\n\t additional info elements: ", length(object@info),"\n")
 
           })
 
