@@ -30,8 +30,8 @@ test_that("test the import of various BIN-file versions", {
 
     ##V6 - show method
     expect_output(
-      read_BIN2R(file = "https://github.com/R-Lum/Luminescence/raw/master/tests/testdata/BINfile_V6.binx",
-                 txtProgressBar = FALSE)
+      suppressWarnings(read_BIN2R(file = "https://github.com/R-Lum/Luminescence/raw/master/tests/testdata/BINfile_V6.binx",
+                 txtProgressBar = FALSE))
     )
 
     ##V7
